=== Applying patches on top of PostgreSQL commit ID fd366065e06ae953c4f2d973d5c5f0474f3b87b6 ===
/etc/rc.d/jail: WARNING: Per-jail configuration via jail_* variables is obsolete. Please consider migrating to /etc/jail.conf.
Wed Mar 4 13:53:26 UTC 2026
On branch cf/6219
nothing to commit, working tree clean
=== using 'git am' to apply patch ./v13-0001-changed-flag-name-to-max-table-segment-pages.patch ===
Applying: * changed flag name to max-table-segment-pages * added check for amname = "heap" * added simple chunked dump and restore test * changed the data type of TableInfo.relpages to BlockNumber, * select it using relpages:oid to get unsigned int out * read it in from query result using strtoul() * removed a bunch of casts from .relpages to (BlocNumber) * changed the data type of TocEntry.dataLength to uint64 current pgoff_t certainly had an overflow in 32bit case when heap relpages + toast relpages > INT_MAX * switched to using of pg_relation_size(c.oid)/current_setting('block_size')::int when --max-table-segment-pages is set * added documentation * added option_parse_uint32(...) to be used for full range of pages numbers
.git/rebase-apply/patch:26: trailing whitespace.
If the number of data pages in the relation is more than npages
.git/rebase-apply/patch:36: trailing whitespace.
In the extreme case a single 8kB heap page can have ~200 toast pointers each
.git/rebase-apply/patch:37: trailing whitespace.
corresponding to 1GB of data. If this data is also non-compressible then a
.git/rebase-apply/patch:132: indent with spaces.
" Number of main table pages above which data is \n"
.git/rebase-apply/patch:158: trailing whitespace.
appendPQExpBuffer(q, "ctid <= '(%u,32000)'", tdinfo->endPage);
warning: squelched 12 whitespace errors
warning: 17 lines add whitespace errors.
Using index info to reconstruct a base tree...
M doc/src/sgml/ref/pg_dump.sgml
M src/bin/pg_dump/pg_backup.h
M src/bin/pg_dump/pg_backup_archiver.c
M src/bin/pg_dump/pg_backup_archiver.h
M src/bin/pg_dump/pg_dump.c
M src/bin/pg_dump/pg_dump.h
Falling back to patching base and 3-way merge...
Auto-merging src/bin/pg_dump/pg_dump.h
Auto-merging src/bin/pg_dump/pg_dump.c
CONFLICT (content): Merge conflict in src/bin/pg_dump/pg_dump.c
Auto-merging src/bin/pg_dump/pg_backup_archiver.h
Auto-merging src/bin/pg_dump/pg_backup_archiver.c
Auto-merging src/bin/pg_dump/pg_backup.h
Auto-merging doc/src/sgml/ref/pg_dump.sgml
error: Failed to merge in the changes.
hint: Use 'git am --show-current-patch=diff' to see the failed patch
Patch failed at 0001 * changed flag name to max-table-segment-pages * added check for amname = "heap" * added simple chunked dump and restore test * changed the data type of TableInfo.relpages to BlockNumber, * select it using relpages:oid to get unsigned int out * read it in from query result using strtoul() * removed a bunch of casts from .relpages to (BlocNumber) * changed the data type of TocEntry.dataLength to uint64 current pgoff_t certainly had an overflow in 32bit case when heap relpages + toast relpages > INT_MAX * switched to using of pg_relation_size(c.oid)/current_setting('block_size')::int when --max-table-segment-pages is set * added documentation * added option_parse_uint32(...) to be used for full range of pages numbers
When you have resolved this problem, run "git am --continue".
If you prefer to skip this patch, run "git am --skip" instead.
To restore the original branch and stop patching, run "git am --abort".
Unstaged changes after reset:
M doc/src/sgml/ref/pg_dump.sgml
M src/bin/pg_dump/pg_backup.h
M src/bin/pg_dump/pg_backup_archiver.c
M src/bin/pg_dump/pg_backup_archiver.h
M src/bin/pg_dump/pg_dump.c
M src/bin/pg_dump/pg_dump.h
M src/bin/pg_dump/t/004_pg_dump_parallel.pl
M src/fe_utils/option_utils.c
M src/include/fe_utils/option_utils.h
=== using patch(1) to apply patch ./v13-0001-changed-flag-name-to-max-table-segment-pages.patch ===
patching file doc/src/sgml/ref/pg_dump.sgml
Hunk #1 succeeded at 1066 (offset -22 lines).
patching file src/bin/pg_dump/pg_backup.h
Hunk #2 succeeded at 180 (offset 1 line).
patching file src/bin/pg_dump/pg_backup_archiver.c
patching file src/bin/pg_dump/pg_backup_archiver.h
patching file src/bin/pg_dump/pg_dump.c
Hunk #1 succeeded at 535 (offset -4 lines).
Hunk #2 succeeded at 800 (offset -4 lines).
Hunk #3 succeeded at 1365 (offset -15 lines).
Hunk #4 FAILED at 2423.
Hunk #5 succeeded at 2438 (offset -1 lines).
Hunk #6 succeeded at 2462 (offset -1 lines).
Hunk #7 succeeded at 2960 (offset -1 lines).
Hunk #8 succeeded at 3172 (offset -1 lines).
Hunk #9 succeeded at 7412 (offset 75 lines).
Hunk #10 succeeded at 7661 (offset 75 lines).
1 out of 10 hunks FAILED -- saving rejects to file src/bin/pg_dump/pg_dump.c.rej
patching file src/bin/pg_dump/pg_dump.h
patching file src/bin/pg_dump/t/004_pg_dump_parallel.pl
patching file src/fe_utils/option_utils.c
patching file src/include/fe_utils/option_utils.h
Unstaged changes after reset:
M doc/src/sgml/ref/pg_dump.sgml
M src/bin/pg_dump/pg_backup.h
M src/bin/pg_dump/pg_backup_archiver.c
M src/bin/pg_dump/pg_backup_archiver.h
M src/bin/pg_dump/pg_dump.c
M src/bin/pg_dump/pg_dump.h
M src/bin/pg_dump/t/004_pg_dump_parallel.pl
M src/fe_utils/option_utils.c
M src/include/fe_utils/option_utils.h
Removing src/bin/pg_dump/pg_dump.c.rej
=== using 'git apply' to apply patch ./v13-0001-changed-flag-name-to-max-table-segment-pages.patch ===
/work/patches/./v13-0001-changed-flag-name-to-max-table-segment-pages.patch:42: trailing whitespace.
If the number of data pages in the relation is more than npages
/work/patches/./v13-0001-changed-flag-name-to-max-table-segment-pages.patch:52: trailing whitespace.
In the extreme case a single 8kB heap page can have ~200 toast pointers each
/work/patches/./v13-0001-changed-flag-name-to-max-table-segment-pages.patch:53: trailing whitespace.
corresponding to 1GB of data. If this data is also non-compressible then a
/work/patches/./v13-0001-changed-flag-name-to-max-table-segment-pages.patch:148: indent with spaces.
" Number of main table pages above which data is \n"
/work/patches/./v13-0001-changed-flag-name-to-max-table-segment-pages.patch:174: trailing whitespace.
appendPQExpBuffer(q, "ctid <= '(%u,32000)'", tdinfo->endPage);
Applied patch to 'doc/src/sgml/ref/pg_dump.sgml' cleanly.
Applied patch to 'src/bin/pg_dump/pg_backup.h' cleanly.
Applied patch to 'src/bin/pg_dump/pg_backup_archiver.c' cleanly.
Applied patch to 'src/bin/pg_dump/pg_backup_archiver.h' cleanly.
Applied patch to 'src/bin/pg_dump/pg_dump.c' with conflicts.
Applied patch to 'src/bin/pg_dump/pg_dump.h' cleanly.
Applied patch to 'src/bin/pg_dump/t/004_pg_dump_parallel.pl' cleanly.
Applied patch to 'src/fe_utils/option_utils.c' cleanly.
Applied patch to 'src/include/fe_utils/option_utils.h' cleanly.
U src/bin/pg_dump/pg_dump.c
warning: squelched 12 whitespace errors
warning: 17 lines add whitespace errors.
diff --cc src/bin/pg_dump/pg_dump.c
index 1035bba72ce,0badb245b55..00000000000
--- a/src/bin/pg_dump/pg_dump.c
+++ b/src/bin/pg_dump/pg_dump.c
@@@ -2404,14 -2419,11 +2415,18 @@@ dumpTableData_copy(Archive *fout, cons
column_list = fmtCopyColumnList(tbinfo, clistBuf);
/*
* Use COPY (SELECT ...) TO when dumping a foreign table's data, and when
* a filter condition was specified. For other cases a simple COPY
* suffices.
*/
++<<<<<<< ours
+ if (tdinfo->filtercond || tbinfo->relkind == RELKIND_FOREIGN_TABLE ||
+ (fout->dopt->binary_upgrade && fout->remoteVersion < 120000 &&
+ tbinfo->dobj.catId.oid == LargeObjectMetadataRelationId))
++=======
+ if (tdinfo->filtercond || is_segment(tdinfo) || tbinfo->relkind == RELKIND_FOREIGN_TABLE)
++>>>>>>> theirs
{
/* Temporary allows to access to foreign tables to dump data */
if (tbinfo->relkind == RELKIND_FOREIGN_TABLE)
@@@ -2404,14 -2419,11 +2415,18 @@@ dumpTableData_copy(Archive *fout, cons
column_list = fmtCopyColumnList(tbinfo, clistBuf);
/*
- * Use COPY (SELECT ...) TO when dumping a foreign table's data, and when
- * a filter condition was specified. For other cases a simple COPY
- * suffices.
+ * Use COPY (SELECT ...) TO when dumping a foreign table's data, when a
+ * filter condition was specified, and when in binary upgrade mode and
+ * dumping an old pg_largeobject_metadata defined WITH OIDS. For other
+ * cases a simple COPY suffices.
*/